@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -48,27 +48,50 @@
  */
 package com.openexchange.usm.database.ox.update;
 
+import java.sql.Connection;
+import java.sql.SQLException;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.PerformParameters;
-import com.openexchange.usm.database.ox.USMTablesUpdateTask;
+import com.openexchange.usm.api.database.StorageAccessException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
+import com.openexchange.usm.database.ox.TableDefinition;
+import com.openexchange.usm.database.ox.USMUpdateExceptionCodes;
 import com.openexchange.usm.database.ox.USMUpdateTaskProvider;
 
 public class USMTablesUpdateTaskV2 extends USMBaseUpdateTaskV2 {
 
-	private final USMTablesUpdateTask _executor;
-
 	public USMTablesUpdateTaskV2(USMUpdateTaskProvider provider) {
 		super(provider);
-		_executor = new USMTablesUpdateTask(provider);
 	}
 
 	@Override
 	protected void doPerform(PerformParameters params) throws OXException {
-		_executor.doPerform(params);
+	    int contextId = params.getContextId();
+        for (int i = 0; i < TableDefinition.TABLE_NAMES.length; i++)
+            createTable(TableDefinition.TABLE_NAMES[i], TableDefinition.SQL_STATEMENTS[i], contextId);
+
+        for (int i = 0; i < TableDefinition.SEQUENCE_TABLES_NAMES.length; i++) {
+            Connection con = null;
+            try {
+                con = _provider.getDatabaseService().getForUpdateTask(contextId);
+                String tablename = TableDefinition.SEQUENCE_TABLES_NAMES[i];
+                TableDefinition.generateSequence(tablename, con, true, !tableExists(tablename,
+                        con.getMetaData()));
+            } catch (SQLException e) {
+                throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
+            } catch (USMStorageException e) {
+                throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
+            } catch (StorageAccessException e) {
+                throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
+            } finally {
+                if (con != null)
+                    _provider.getDatabaseService().backWritable(contextId, con);
+            }
+        }
 	}
 
 	@Override
     public String[] getDependencies() {
-		return new String[] { USMTablesUpdateTask.class.getName() };
+		return new String[] { };
 	}
 }
