@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,7 +61,6 @@ import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID
 import static com.openexchange.usm.connector.commands.CommandConstants.SYNCID;
 import static com.openexchange.usm.json.response.ResponseStatusCode.*;
 import static com.openexchange.usm.json.ConnectorBundleErrorCodes.*;
-
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
@@ -71,15 +70,11 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
-
 import javax.servlet.http.HttpServletRequest;
-
 import org.json.JSONArray;
 import org.json.JSONObject;
-
 import com.openexchange.usm.api.contenttypes.common.ContentType;
 import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.folder.FolderConstants;
 import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.exceptions.InvalidUUIDException;
@@ -185,6 +180,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
             }
             syncId = finishProcessingAndSaveNewState(_syncResult, _folderToSync, syncId);
             JSONObject response = createResponseFromSyncResults(_syncResult, syncId);
+            _swapUUIDsMap.clear();
             logSyncData(" syncUpdate", folderUUID, _syncID, syncId, _syncResult.getTimestamp());
             if (usedOldSyncKey || isUnnecessaryAccess(folderUUID, response))
                 _servlet.getAccessLimiter().badAccessEncountered(_session);
@@ -331,8 +327,12 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 				_folderClientChangesArray = filterFoldersWithErrors(createFolderChangesArray(syncId));
 				Arrays.sort(_folderClientChangesArray, new FolderHierarchyComparator(_folderClientChangesArray,
 						_servlet.getJournal()));
-				return _session.syncFolderChangesWithServer(syncId, _limit, null, true, conflictResolution,
+				SyncResult result = _session.syncFolderChangesWithServer(syncId, _limit, null, true, conflictResolution,
                     _folderClientChangesArray);
+
+				JSONArray deleted = new JSONArray();
+				findSwappedStandardFolders(buildClientChangesArray(result.getChanges(), deleted), result.getNewState());
+				return result;
 			}
 			_serverChangesMayBeAvailable = _session.needsSynchronization(_folderToSync.getID());
 			_clientChangesArray = filterDataObjectsWithErrors(buildClientRequestArray(_folderToSync, syncId, conflictResolution));
@@ -380,35 +380,6 @@ public class SyncUpdateHandler extends SyncCommandHandler {
         return notExistingStandardFolders;
     }
 
-    /**
-     * @param folder
-     * @param useOriginalContent for modifications, determine if the current or original content of the object should be used
-     * @return standard_folder_type if required standard folder, otherwise 0
-     */
-    private static int getRequiredStandardFolderType(DataObject folder, boolean useOriginalContent) {
-        Object fieldValue = useOriginalContent ? folder.getOriginalFieldContent(FolderConstants.STANDARD_FOLDER) : folder.getFieldContent(FolderConstants.STANDARD_FOLDER);
-        if (!(fieldValue instanceof Boolean) || !((Boolean) fieldValue).booleanValue())
-            return 0; // No standard folder -> not required
-        fieldValue = useOriginalContent ? folder.getOriginalFieldContent(FolderConstants.STANDARD_FOLDER_TYPE) : folder.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
-        if (fieldValue instanceof Number) {
-            int standardFolderType = ((Number) fieldValue).intValue();
-            switch (standardFolderType) {
-            case 1: // Task
-            case 2: // Calendar
-            case 3: // Contact
-            case 7: // Inbox
-            case 9: // Drafts
-            case 10: // Sent
-            case 11: // Spam
-            case 12: // Trash
-                return standardFolderType;
-            default:
-                break;
-            }
-        }
-        return 0;
-    }
-
     private Folder[] createFolderChangesArray(long syncId) throws StorageAccessException, USMStorageException,
 			USMJSONAPIException, SlowSyncRequiredException {
 		Folder[] originalFolders = _session.getCachedFolders(syncId);
