@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -173,7 +173,8 @@ public class SessionImpl implements Session {
     
     private long _startDateCalendar = 0L;
 
-    private long _endDateCalendar = Long.MAX_VALUE;
+    // Similar to BaseXMLDelegate.getTimeFrame set on now + 3 years
+    private long _endDateCalendar = System.currentTimeMillis() + 3L * 365L * 86400L * 1000L;
 
     private int _mailLimit = 0;
 
@@ -640,6 +641,7 @@ public class SessionImpl implements Session {
     }
 
     public long storeCachedDataObjects(String folderID, long oldTimestamp, long timestamp, DataObjectSet objects, boolean updatesPending) throws USMException {
+        // TODO: Why do we ignore the returned set?
         checkValidObjectsForSyncState(folderID, objects.toArray());
         long result = internalStoreCachedDataObjects(getShortFolderID(folderID), oldTimestamp, timestamp, objects);
         if (updatesPending)
